ServiceWorkerPayload class

Implemented types

Constructors

ServiceWorkerPayload(NotificationAction action, {String? id, JSNotification? notification, Map<String, dynamic>? data})
ServiceWorkerPayload.cancel(String id)
factory
ServiceWorkerPayload.cancelAll()
factory

Properties

action → NotificationAction
final
data → Map<String, dynamic>?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
notification → JSNotification?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited